@@ -4,21 +4,20 @@ import os
 
 
 class IgnoresDB(object):
-
     def __init__(self):
-        self._filename = '.package_ignores'
+        self._filename = ".package_ignores"
         if not os.path.isfile(self._filename):
-            open(self._filename, 'w').close()
+            open(self._filename, "w").close()
 
-        with open(self._filename, 'r') as f:
+        with open(self._filename, "r") as f:
             content = f.read()
-            if content != '':
+            if content != "":
                 self._db = json.loads(content)
             else:
                 self._db = {}
 
     def save(self):
-        with open(self._filename, 'w+') as f:
+        with open(self._filename, "w+") as f:
             f.write(json.dumps(self._db))
 
     def get(self, package_name):
