@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
-import xmlrpclib
+from six.moves.xmlrpc_client import ServerProxy
 
 
 def get_users_with_release_rights(package_name):
-    client = xmlrpclib.ServerProxy('https://pypi.python.org/pypi')
-    existing_admins = set([
-        user for role, user in client.package_roles(package_name)])
+    client = ServerProxy("https://pypi.org/pypi")
+    existing_admins = set([user for role, user in client.package_roles(package_name)])
     return existing_admins
 
 
